@@ -1,10 +1,11 @@
 '''
+[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)
 [![GitHub](https://img.shields.io/github/license/pepperize/cdk-private-bucket?style=flat-square)](https://github.com/pepperize/cdk-private-bucket/blob/main/LICENSE)
 [![npm (scoped)](https://img.shields.io/npm/v/@pepperize/cdk-private-bucket?style=flat-square)](https://www.npmjs.com/package/@pepperize/cdk-private-bucket)
 [![PyPI](https://img.shields.io/pypi/v/pepperize.cdk-private-bucket?style=flat-square)](https://pypi.org/project/pepperize.cdk-private-bucket/)
 [![Nuget](https://img.shields.io/nuget/v/Pepperize.CDK.PrivateBucket?style=flat-square)](https://www.nuget.org/packages/Pepperize.CDK.PrivateBucket/)
 [![Sonatype Nexus (Releases)](https://img.shields.io/nexus/r/com.pepperize/cdk-private-bucket?server=https%3A%2F%2Fs01.oss.sonatype.org%2F&style=flat-square)](https://s01.oss.sonatype.org/content/repositories/releases/com/pepperize/cdk-private-bucket/)
-[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/pepperize/cdk-private-bucket/release/main?label=release&style=flat-square)](https://github.com/pepperize/cdk-private-bucket/actions/workflows/release.yml)
+[![GitHub Workflow Status (branch)](https://img.shields.io/github/actions/workflow/status/pepperize/cdk-private-bucket/release.yml?branch=main&label=release&style=flat-square)](https://github.com/pepperize/cdk-private-bucket/actions/workflows/release.yml)
 [![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/pepperize/cdk-private-bucket?sort=semver&style=flat-square)](https://github.com/pepperize/cdk-private-bucket/releases)
 
 # AWS CDK Private Bucket
@@ -91,6 +92,26 @@ import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
 import constructs as _constructs_77d1e7e8
 
 
+@jsii.implements(_aws_cdk_ceddda9d.IAspect)
+class BucketPrivacy(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@pepperize/cdk-private-bucket.BucketPrivacy",
+):
+    def __init__(self) -> None:
+        jsii.create(self.__class__, self, [])
+
+    @jsii.member(jsii_name="visit")
+    def visit(self, node: _constructs_77d1e7e8.IConstruct) -> None:
+        '''All aspects can visit an IConstruct.
+
+        :param node: -
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7a3dba4368882a4739e2626ead40f3a4883c99d077612835862216ab828bfb6c)
+            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
+        return typing.cast(None, jsii.invoke(self, "visit", [node]))
+
+
 class PrivateBucket(
     _aws_cdk_aws_s3_ceddda9d.Bucket,
     metaclass=jsii.JSIIMeta,
@@ -659,12 +680,19 @@ class PrivateBucketProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
 
 
 __all__ = [
+    "BucketPrivacy",
     "PrivateBucket",
     "PrivateBucketProps",
 ]
 
 publication.publish()
 
+def _typecheckingstub__7a3dba4368882a4739e2626ead40f3a4883c99d077612835862216ab828bfb6c(
+    node: _constructs_77d1e7e8.IConstruct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__12c21179f9e7bb44a50659259407e96dc6e1f1b6b4428f047f629d9fe45b16e0(
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
